# E-Flux (combining Expression Data with Fluxes)

[![Actions status](https://github.com/pnnl-predictive-phenomics/eflux/workflows/CI/badge.svg)](https://github.com/pnnl-predictive-phenomics/eflux/actions)
[![Rye](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/rye/main/artwork/badge.json)](https://rye-up.com)
[![License](https://img.shields.io/badge/License-BSD_2--Clause-orange.svg)](https://opensource.org/licenses/BSD-2-Clause)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

Package to run E-Flux on `cobra` models with provided transcriptomics expression data.


## Getting Started 🏃

To get started run the following:

```python
from eflux import eflux2

eflux2(cobra_model, transcriptomics)
```

## Installation 🪛

The most recent code and data can be installed directly from GitHub with:

```shell
pip install git+https://github.com/pnnl-predictive-phenomics/eflux.git
```

## License 📄

The code in this package is licensed under the BSD-2 License.


## Contributing 👋
To contribute to this package, please reference [CONTRIBUTING.md](CONTRIBUTING.md)
